LoggerFunction typedef

LoggerFunction = void Function(String message)

A function that accepts a message string and does something with it, such as logging it, ...

Implementation

typedef LoggerFunction = void Function(String message);